@@ -1,10 +1,10 @@
 from .presence import *
 from .button import button
 from .exceptions import *
-from .get_current_app import GCAR
+#from .get_current_app import GCAR (Disabling due to a bug)
 
 __title__ = "Discord-RPC"
-__version__ = "3.0"
+__version__ = "3.5"
 __authors__ = "LyQuid"
 __license__ = "Apache License 2.0"
 __copyright__ = "Copyright 2021-present LyQuid"
