@@ -129,15 +129,15 @@ class RPC(metaclass=ABCMeta):
         state:str=None, 
         details:str=None,
         timestamp=None, 
-        small_text:str=None, 
-        large_text:str=None,
-        small_image:str=None, 
-        large_image:str=None,
+        small_text:str='null', 
+        large_text:str='null',
+        small_image:str='null', 
+        large_image:str='null',
         buttons=None
     ): 
 
-        r"""
-        A method for set RPC activity
+        """
+        A method for set RPC activity.
         -------
         Parameters :
         - state: `str`
@@ -148,25 +148,17 @@ class RPC(metaclass=ABCMeta):
         - small_image: `str` | must be the same as image name in application assets
         - large_image: `str` | must be the same as image name in application assets
         - buttons: `str` | use DiscordRPC.button() method
+
+        Required to add `run()` method!
         """
         
-        if large_image == None:
-           large_image = 'null'
-        if small_image == None:
-            small_image = 'null'
-        if small_text == None:
-            small_text = 'null'
-        if large_text == None:
-            large_text = 'null'
-        else:
-            if len(large_text) <= 3:
-                raise Error('"large text" must be at least above 3 characters')
+        if len(large_text) <= 3:
+            raise Error('"large text" must be at least above 3 characters')
 
-            if len(small_text) <= 3:
-                raise Error('"small text" must be at least above 3 characters')
+        if len(small_text) <= 3:
+            raise Error('"small text" must be at least above 3 characters')
 
-        if buttons == None:
-            act = {
+        act = {
             "state": state,
             "details": details,
             "timestamps": {
@@ -174,27 +166,21 @@ class RPC(metaclass=ABCMeta):
             },
             "assets": {
                 "small_text": small_text,
-                "small_image": str(small_image),
                 "large_text": large_text,
+                "small_image": str(small_image),
                 "large_image": str(large_image)
-            }
+            },
+            "buttons": buttons,
         }
 
-        else:
-            act = {
-                "state": state,
-                "details": details,
-                "timestamps": {
-                    "start": timestamp
-                },
-                "assets": {
-                    "small_text": small_text,
-                    "small_image": str(small_image),
-                    "large_text": large_text,
-                    "large_image": str(large_image)
-                },
-                "buttons": buttons,
-            }
+        if small_text == 'null':
+            act['assets'].pop('small_text', None)
+        if large_text == 'null':
+            act['assets'].pop('large_text', None)
+        if timestamp == None:
+            act.pop('timestamps', None)
+        if buttons == None:
+            act.pop('buttons', None)
 
         data = {
             'cmd': 'SET_ACTIVITY',
@@ -218,9 +204,19 @@ class RPC(metaclass=ABCMeta):
         return op, output
 
     def output(self):
+        """
+        A method to print RPC output.
+        """
         output = self.get_output
         return output
 
+    def run(self):
+        """
+        A method to run RPC. It's REQUIRED.
+        """
+        while True:
+            time.sleep(1)
+
 
 class DiscordWindows(RPC):
 
@@ -288,4 +284,4 @@ class DiscordUnix(RPC):
         return self._sock.recv(size)
 
     def _close(self):
-        self._sock.close()
+        self._sock.close()
\ No newline at end of file
